/**
* EasyBeans
* Copyright (C) 2006 Bull S.A.S.
* Contact: easybeans@objectweb.org
*
* This library is free software; you can redistribute it and/or
* modify it under the terms of the GNU Lesser General Public
* License as published by the Free Software Foundation; either
* version 2.1 of the License, or any later version.
*
* This library is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
* Lesser General Public License for more details.
*
* You should have received a copy of the GNU Lesser General Public
* License along with this library; if not, write to the Free Software
* Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
* USA
*
* --------------------------------------------------------------------------
* $Id: EZBArchive.java 952 2006-07-26 16:30:27Z sauthieg $
* --------------------------------------------------------------------------
*/

package org.objectweb.easybeans.api;

import java.net.URL;
import java.util.Iterator;

/**
* Abstraction layer around EZB processed archive (Jar, Directories, Bundles, ...).
* @author Guillaume Sauthier
*/
public interface EZBArchive {

    /**
     * @return a description of this archive. This name could be used in logger info.
     */
    String getName();

   /**
    * @return Returns the resource URL.
    * @throws EZBArchiveException if method fails.
    */
   URL getURL() throws EZBArchiveException;

   /**
    * @param resourceName The resource name to be looked up.
    * @return Returns the resource URL if the resource
    *         has been found. null otherwise.
    * @throws EZBArchiveException if method fails.
    */
   URL getResource(String resourceName) throws EZBArchiveException;

   /**
    * @return Returns an Iterator of Resource's URL.
    * @throws EZBArchiveException if method fails.
    */
   Iterator<URL> getResources() throws EZBArchiveException;

   /**
    * @param resourceName The resource name to be looked up.
    * @return Returns an Iterator of matching resources.
    * @throws EZBArchiveException if method fails.
    */
   Iterator<URL> getResources(String resourceName) throws EZBArchiveException;

   /**
    * Close the underlying Resource.
    * @return Returns <code>true</code> if the close was
    *         succesful, <code>false</code> otherwise.
    */
   boolean close();
}
